@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# vim: set fileencoding=utf-8 :
 #
 # Copyright 2013 jKey Lu
 #
@@ -208,5 +209,5 @@ def parse_link(link):
 
 def get_last_page_num(link):
     linkmap = parse_link(link)
-    matches = re.search(r"page=(\d+)", linkmap["last"])
+    matches = re.search(r"[?&]page=(\d+)", linkmap["last"])
     return int(matches.group(1))
